@@ -14,18 +14,6 @@ class GPSInfoHeader():
         for key in self._fields:
             yield (key, self._fields[key],)
 
-    @classmethod
-    def get_map_link(self, N=0, W=0):
-        ndeg = str(round(float(N[0]),2))
-        nhour = str(round(float(N[1]),2))
-        nsec = f"{round(float(N[2]),2):.2f}"
-        wdeg = str(round(float(W[0]),2))
-        whour = str(round(float(W[1]),2))
-        wsec = f"{round(float(W[2]),2):.2f}"
-
-        # build the link in a way that the string can be read on the command line
-        return r"https://www.google.com/maps/place/" + ndeg+r"°"+nhour+r"\'"+nsec+r'\"N+' + wdeg+r'°'+whour+r"\'"+wsec+r'\"W/'
-
 class GPSInfoHeaderEncoder(json.JSONEncoder):
     def default(self, o):
         return o.__dict__
@@ -128,10 +116,6 @@ class ExifHeaderListParser():
                         else:
                             gps_info_header[gk] = gps_info[gk]
 
-                    gps_info_header['MapLink'] = GPSInfoHeader.get_map_link(
-                        N=gps_info_header['GPSLatitude'],
-                        W=gps_info_header['GPSLongitude'],
-                    )                   
             fields = {
                 **{k:f for k, f in exif_header.items()},
                 'GPSInfo': GPSInfoHeader(**gps_info_header)._fields
